{% extends 'base.html' %}
{% block title %}Log in{% endblock %}
{% block header %}{% endblock %}

{% block content %}
<div class="content-login">
  <form class="form-login" method="post">
    {{ form.hidden_tag() }}
    {{
      form.password(
        type='password',
        id='password',
        class_='form-control',
        placeholder='Password',
        autofocus=True,
        required=True
      )
    }}
    {{
      form.password2(
        type='password',
        id='password2',
        class_='form-control',
        placeholder='Repeat Password',
        required=True
      )
    }}
    {{ form.submit(class_="btn btn-lg btn-outline-primary btn-block") }}
  </form>
</div>
{% endblock %}