{% extends 'base.html' %}
{% block title %}Log in{% endblock %}
{% block header %}{% endblock %}

{% block content %}
<div class="content-login">
  <p class="lead">
    This app is a simple implementation of the <a href="https://engineeredportfolio.com/2018/05/02/accelerating-dual-momentum-investing/">Accelerated Dual Momentum</a>
    investment strategy. It queries a Yahoo Finance API for historical ticker
    price data, calculates ADM statistics, and suggests a strategy.
  </p>
</div>
<div class="content-login">
  <form class="form-login" method="post">
    {{ form.hidden_tag() }}
    {{
      form.username(
        id='username',
        class_='form-control',
        placeholder='Username',
        required=True,
        autofocus=True
      )
    }}
    {{
      form.password(
        type='password',
        id='password',
        class_='form-control',
        placeholder='Password',
        required=True
      )
    }}
    {{ form.submit(class_="btn btn-lg btn-outline-primary btn-block") }}
  </form>
  <p><a href="{{ url_for('auth.reset_password_request') }}">Reset Password</a></p>
</div>
{% endblock %}
