<!doctype html>
<html lang='en'>

<head>
  <!-- Required meta tags -->
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

  <!-- Other meta tags -->
  <meta name="description" content="">
  <meta name="author" content="">

  <!-- Bootstrap CSS -->
  <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.1.1/css/bootstrap.min.css" integrity="sha384-WskhaSGFgHYWDcbwN70/dfYBj47jz9qbsMId/iRN3ewGhXQFZCSftd1LZCfmhktB"
    crossorigin="anonymous">
  
  <!-- Local CSS -->
  <link rel="stylesheet" href="{{ url_for('static', filename='style.css') }}">
  
  <title>Accelerated Dual Momentum</title>
</head>

<nav class="navbar navbar-expand-md navbar-primary bg-primary fixed-top">
  <h1 class="nav-header">Accelerated Dual Momentum</h1>
  <ul>
    {% if current_user.is_anonymous %}
    <li><a href="{{ url_for('auth.register') }}">Register</a>
    <li><a href="{{ url_for('auth.login') }}">Log In</a>
    {% else %}
    <li><span>{{ current_user.username }}</span>
    <li><a href="{{ url_for('strategy.index') }}">Home</a>
    <li><a href="{{ url_for('settings.index') }}">Settings</a>
    <li><a href="{{ url_for('auth.logout') }}">Log Out</a>
    {% endif %}
  </ul>
</nav>

<section class="content">
  <header>
    {% block header %}{% endblock %}
  </header>
  {% for message in get_flashed_messages() %}
  <div class="flash">{{ message }}</div>
  {% endfor %}
  {% block content %}{% endblock %}
</section>
</html>