{% extends 'base.html' %}
{% block title %}Register{% endblock %}
{% block header %}{% endblock %}

{% block content %}
<div class='content-login'>
  <form class="form-login" method="post">
    {{ form.hidden_tag() }}
    {{
      form.username(
        id='username',
        class_='form-control',
        placeholder='Username',
        required=True,
        autofocus=True
      )
    }}
    {{
      form.email(
        type='email',
        id='email',
        class_='form-control',
        placeholder='Email',
        required=True
      )
    }}
    {{
      form.password(
        type='password',
        id='password',
        class_='form-control',
        placeholder='Password',
        required=True
      )
    }}
    {{
      form.password2(
        type='password',
        id='password2',
        class_='form-control',
        placeholder='Repeat password',
        required=True
      )
    }}
    {{ form.submit(class_="btn btn-lg btn-outline-primary btn-block") }}
  </form>
</div>
{% endblock %}
